#include <bits/stdc++.h>
#include "testlib.h"
#define ff first
#define ss second
#define szof(_x) ((int) (_x).size())

using namespace std;
typedef long long ll;
typedef pair<int, int> pii;
const int INF = 1e9 + 7;
const ll INFL = 9e18 + 123;
const double PI = atan2(0, -1);

struct point {
	int x, y;
	point(int _x, int _y) : x(_x), y(_y) {}

	ll len2() {
		return (ll) x * x + (ll) y * y;
	}

	bool operator<(point other) {
		return x < other.x || (x == other.x && y < other.y);
	}

	bool operator!=(point other) {
		return x != other.x || y != other.y;
	}

	point operator+(point other) {
		return point(x + other.x, y + other.y);
	}

	point operator-(point other) {
		return point(x - other.x, y - other.y);
	}

	point operator-() {
		return point(-x, -y);
	}
};

ll cross(point p1, point p2) {
	return (ll) p1.x * p2.y - (ll) p1.y * p2.x;
}

ll scalar(point p1, point p2) {
	return (ll) p1.x * p2.x + (ll) p1.y * p2.y;
}

bool cmp(point p1, point p2) {
	bool fl1 = p1.y > 0 || (p1.y == 0 && p1.x > 0);
	bool fl2 = p2.y > 0 || (p2.y == 0 && p2.x > 0);
	if (fl1 != fl2) {
		return fl1 < fl2;
	}
	ll tmp = cross(p1, p2);
	if (tmp) {
		return tmp > 0;
	}
	return p1.len2() < p2.len2();
}

vector<point> convex_hull(vector<point> arr) {
	vector<point> res;
	int mem = 0;
	for (int i = 0; i < szof(arr); ++i) {
		if (arr[i] < arr[mem]) {
			mem = i;
		}
	}

	point center = arr[mem];

	for (auto p : arr) {
		if (p != center) {
			res.push_back(p - center);
		}
	}
	swap(res, arr);
	res = {point(0, 0)};

	sort(arr.begin(), arr.end(), cmp);
	arr.push_back(point(0, 0));

	for (auto p : arr) {
		while (szof(res) >= 2) {
			auto& p1 = res[szof(res) - 2];
			auto& p2 = res[szof(res) - 1];
			ll val_cross = cross(p2 - p1, p - p2);
			if (val_cross < 0 || (val_cross == 0 && p != point(0, 0))) {
				res.pop_back();
			} else {
				break;
			}
		}
		res.push_back(p);
	}

	res.pop_back();
	for (auto& p : res) {
		p = p + center;
	}

	return res;
}

bool intersects(vector<point> poly1, vector<point> poly2) {
	for (auto& p : poly2) {
		p = -p;
	}

	vector<point> all;

	int start1 = 0;
	for (int i = 0; i < szof(poly1); ++i) {
		if (poly1[i].y > poly1[start1].y || (poly1[i].y == poly1[start1].y && poly1[i].x > poly1[start1].x)) {
			start1 = i;
		}
		int next = (i + 1) % szof(poly1);
		all.push_back(poly1[next] - poly1[i]);
	}

	int start2 = 0;
	for (int i = 0; i < szof(poly2); ++i) {
		if (poly2[i].y > poly2[start2].y || (poly2[i].y == poly2[start2].y && poly2[i].x > poly2[start2].x)) {
			start2 = i;
		}
		int next = (i + 1) % szof(poly2);
		all.push_back(poly2[next] - poly2[i]);
	}

	point cur = poly1[start1] + poly2[start2];

	sort(all.begin(), all.end(), cmp);

	vector<point> res;
	for (auto p : all) {
		res.push_back(cur);
		cur = cur + p;
	}

	ll minval = INFL, maxval = -INFL;

	for (int i = 0; i < szof(res); ++i) {
		int next = (i + 1) % szof(res);

		ll val = cross(res[i], res[next]);
		ll sc = scalar(res[i], res[next]);
		if (!val && sc > 0) {
			continue;
		}
		minval = min(minval, val);
		maxval = max(maxval, val);
	}

	if (minval == INFL) {
		return false;
	}

	if (minval < 0 && maxval > 0) {
		return false;
	}
	return true;
}

vector<point> inp;
int n;

int check_outp(auto& stream, auto bad_outcome, string const& who) {
	int sz = stream.readInt(1, n);
	vector<point> part1, part2;
	vector<bool> used(n);
	set<int> inds;
	for (int i = 0; i < sz; ++i) {
		int ind = stream.readInt(1, n) - 1;
		if (inds.count(ind)) {
			quitf(bad_outcome, "%s has incorrect solution, two equal indices", who.c_str());
		}
		inds.insert(ind);
		part1.push_back(inp[ind]);
		used[ind] = true;
	}

	for (int i = 0; i < n; ++i) {
		if (!used[i]) {
			part2.push_back(inp[i]);
		}
	}

	if (!intersects(convex_hull(part1), convex_hull(part2))) {
		quitf(bad_outcome, "%s has incorrect solution, polygons don't intersect", who.c_str());
	}

	return sz;
}

int main(int argc, char* argv[]) {
	setName("compare two outputs");
	registerTestlibCmd(argc, argv);

	n = inf.readInt();
	
	for (int i = 0; i < n; ++i) {
		int x = inf.readInt();
		int y = inf.readInt();
		inp.push_back(point(x, y));
	}

	int jsz = check_outp(ans, _fail, "jury");
	int psz = check_outp(ouf, _wa, "participant");

	if (jsz < psz) {
		quitf(_wa, "participant has worse solution than jury, (%d, %d) instead of (%d, %d)", psz, n - psz, jsz, n - jsz);
	}

	if (psz < jsz) {
		quitf(_fail, "participant has better solution than jury, (%d, %d) instead of (%d, %d)", psz, n - psz, jsz, n - jsz);
	}

	quitf(_ok, "participant has correct solution");

	return 0;
}